@@ -1,4 +1,4 @@
-use std::fmt::{Debug, Display};
+use std::fmt::Debug;
 
 use nom::{
     bytes::streaming,
@@ -7,6 +7,7 @@ use nom::{
     number, AsChar, IResult, Needed,
 };
 
+pub mod cr3_moov;
 mod idat;
 mod iinf;
 mod iloc;
@@ -15,6 +16,8 @@ mod keys;
 mod meta;
 mod mvhd;
 mod tkhd;
+mod uuid;
+pub use cr3_moov::Cr3MoovBox;
 pub use ilst::IlstBox;
 pub use keys::KeysBox;
 pub use meta::MetaBox;
@@ -23,23 +26,6 @@ pub use tkhd::parse_video_tkhd_in_moov;
 
 const MAX_BODY_LEN: usize = 2000 * 1024 * 1024;
 
-#[derive(Debug, PartialEq)]
-pub enum Error {
-    UnsupportedConstructionMethod(u8),
-}
-
-impl std::error::Error for Error {}
-
-impl Display for Error {
-    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        match self {
-            Error::UnsupportedConstructionMethod(x) => {
-                Debug::fmt(&format!("unsupported construction method ({x})"), f)
-            }
-        }
-    }
-}
-
 /// Representing an ISO base media file format box header.
 #[derive(Debug, Clone, PartialEq, Eq)]
 pub struct BoxHeader {
