@@ -21,7 +21,7 @@ use crate::{
     EntryValue, FileFormat,
 };
 
-/// *Deprecated*: Please use [`MediaParser`] instead.
+/// *Deprecated*: Please use [`crate::MediaParser`] instead.
 ///
 /// Analyze the byte stream in the `reader` as a MOV/MP4 file, attempting to
 /// extract any possible metadata it may contain, and return it in the form of
@@ -130,7 +130,7 @@ pub fn parse_metadata<R: Read + Seek>(reader: R) -> crate::Result<Vec<(String, E
 }
 
 #[tracing::instrument(skip_all)]
-pub(crate) fn parse_qt(
+pub(crate) fn parse_isobmff(
     moov_body: &[u8],
 ) -> Result<BTreeMap<TrackInfoTag, EntryValue>, ParsingError> {
     let (_, entries) = match parse_moov_body(moov_body) {
@@ -142,34 +142,15 @@ pub(crate) fn parse_qt(
     };
 
     let mut entries: BTreeMap<TrackInfoTag, EntryValue> = convert_video_tags(entries);
-    let extras = parse_mvhd_tkhd(moov_body);
+    let mut extras = parse_mvhd_tkhd(moov_body);
     if entries.contains_key(&TrackInfoTag::CreateDate) {
-        entries.remove(&TrackInfoTag::CreateDate);
+        extras.remove(&TrackInfoTag::CreateDate);
     }
     entries.extend(extras);
 
     Ok(entries)
 }
 
-#[tracing::instrument(skip_all)]
-pub(crate) fn parse_mp4(
-    moov_body: &[u8],
-) -> Result<BTreeMap<TrackInfoTag, EntryValue>, ParsingError> {
-    let (_, entries) = match parse_moov_body(moov_body) {
-        Ok((remain, Some(entries))) => (remain, entries),
-        Ok((remain, None)) => (remain, Vec::new()),
-        Err(_) => {
-            return Err("invalid moov body".into());
-        }
-    };
-
-    let mut entries: BTreeMap<TrackInfoTag, EntryValue> = convert_video_tags(entries);
-    let extras = parse_mvhd_tkhd(moov_body);
-    entries.extend(extras);
-
-    Ok(entries)
-}
-
 fn parse_mvhd_tkhd(moov_body: &[u8]) -> BTreeMap<TrackInfoTag, EntryValue> {
     let mut entries = BTreeMap::new();
     if let Ok((_, Some(bbox))) = find_box(moov_body, "mvhd") {
@@ -377,7 +358,7 @@ pub(crate) fn extract_moov_body_from_buf(input: &[u8]) -> Result<Range<usize>, P
 type EntriesResult<'a> = IResult<&'a [u8], Option<Vec<(String, EntryValue)>>>;
 
 #[tracing::instrument(skip(input))]
-fn parse_moov_body(input: &[u8]) -> EntriesResult {
+fn parse_moov_body(input: &[u8]) -> EntriesResult<'_> {
     tracing::debug!("parse_moov_body");
 
     let mut entries = parse_meta(input).unwrap_or_default();
